"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

require("universal-dotenv");

var _path = _interopRequireDefault(require("path"));

var _fs = require("fs");

var _os = require("os");

var _listr = _interopRequireDefault(require("listr"));

var _clearConsole = _interopRequireDefault(require("react-dev-utils/clearConsole"));

var _execa = _interopRequireDefault(require("execa"));

var _commander = _interopRequireDefault(require("commander"));

var _ngrok = require("ngrok");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// eslint-disable-line import/no-extraneous-dependencies
async function start({
  web = true,
  node = true,
  mongod,
  redis,
  ngrok: ngrokArg
} = {}) {
  const {
    env: {
      PORT = 3000,
      MONGOD_PORT = 27017,
      REDIS_PORT = 6379,
      BROWSER,
      HTTPS,
      NODE_ENV,
      PUBLIC_URL,
      ...env
    }
  } = process;

  if (NODE_ENV === 'production') {
    return (0, _execa.default)('node', [(0, _fs.existsSync)('./lib/index.node.js') ? 'lib/index.node' : 'lib'], {
      stdio: 'inherit'
    });
  }

  await new _listr.default([{
    title: 'Downloading mongod',
    enabled: () => mongod && !(0, _fs.existsSync)(_path.default.resolve((0, _os.homedir)(), '.mongodb-prebuilt')),
    task: () => (0, _execa.default)('mongod', ['--version']).stdout
  }, {
    title: 'Downloading redis',
    enabled: () => redis && !(0, _fs.existsSync)(_path.default.resolve((0, _os.homedir)(), '.redis-prebuilt')),
    task: () => (0, _execa.default)('redis-server', ['--version']).stdout
  }], {
    renderer: NODE_ENV === 'test' ? 'silent' :
    /* istanbul ignore next */
    'default',
    exitOnError: false,
    concurrent: true
  }).run();

  if (process.stdout.isTTY) {
    (0, _clearConsole.default)();
  }
  /*
   * https://github.com/strongloop/node-foreman/blob/master/lib/colors.js#L7
   * The order dictates the color
   */


  const formation = Object.entries({
    node,
    // magenta
    foo2: false,
    // blue
    web,
    // cyan
    mongod,
    // green
    foo5: false,
    // yellow
    redis // red

  });
  const ngrok = ngrokArg && web;
  const NGROK_URL = ngrok ? await (0, _ngrok.connect)({
    bind_tls: HTTPS === 'true',
    host_header: 'localhost',
    port: PORT
  }) : undefined;
  return (0, _execa.default)('nf', ['start', '--procfile', _path.default.resolve(__dirname, 'Procfile'), formation.slice(0, formation.map(([, val]) => val).lastIndexOf(true) + 1).map(([key, val], index) => val ? `${key}=1` : `foo${index + 1}=0`).join(',')], {
    env: { ...env,
      NODE_ENV: 'development',
      BROWSER,
      HTTPS,
      PORT,
      ...(web && {
        WEB_PORT_OFFSET: -100 * formation.findIndex(([key]) => key === 'web'),
        SKIP_PREFLIGHT_CHECK: true
      }),
      ...(node && {
        NODE_PORT_OFFSET: 1000 - 100 * formation.findIndex(([key]) => key === 'node'),
        src: (0, _fs.existsSync)('./src/index.node.js') ? 'src/index.node' : 'src',
        root: __dirname
      }),
      ...(mongod && {
        MONGOD_PORT,
        MONGODB_URI: `mongodb://localhost:${MONGOD_PORT}/database`,
        MONGOHQ_URL: `mongodb://localhost:${MONGOD_PORT}/database`,
        ORMONGO_URL: `mongodb://localhost:${MONGOD_PORT}/database`
      }),
      ...(redis && {
        REDIS_PORT,
        OPENREDIS_URL: `redis://localhost:${REDIS_PORT}`,
        REDISCLOUD_URL: `redis://localhost:${REDIS_PORT}`,
        REDISGREEN_URL: `redis://localhost:${REDIS_PORT}`,
        REDISTOGO_URL: `redis://localhost:${REDIS_PORT}`,
        REDIS_URL: `redis://localhost:${REDIS_PORT}`
      }),
      ...(ngrok && {
        NGROK_URL,
        BROWSER: _path.default.resolve(__dirname, 'open-ngrok.js'),
        REAL_BROWSER: BROWSER,
        HTTPS: false
      })
    },
    stdio: 'inherit'
  });
}
/* istanbul ignore next line */


if (require.main === module) {
  _commander.default.option('--mongod').option('--redis').option('--ngrok').option('--no-web').option('--no-node').parse(process.argv);

  start(_commander.default).catch(err => {
    // eslint-disable-line promise/prefer-await-to-callbacks
    const {
      errors = []
    } = err;
    /* istanbul ignore next line */

    errors.filter(({
      stdout
    }) => stdout).forEach(({
      stdout
    }) => console.log(stdout)); // eslint-disable-line no-console

    /* istanbul ignore next line */

    errors.filter(({
      stderr
    }) => stderr).forEach(({
      stderr
    }) => console.error(stderr)); // eslint-disable-line no-console

    process.exit(err.code || (errors.find(({
      code
    }) => code) || {}).code || 1);
  });
}

var _default = start;
exports.default = _default;
//# sourceMappingURL=react-node-scripts-start.js.map